import { AbstractClient } from "./abstract_client";
import { BY_ID_QUERIES } from "./by_id_queries";
import { CONNECTION_QUERIES } from "./connection_queries";
import { LIST_QUERIES } from "./list_queries";
export class TFGridGqlClient extends AbstractClient {
    constructor(url) {
        super();
        this.__uri = url;
    }
    async _request(options) {
        const { name, parameters, query, variables } = options;
        const p = parameters && parameters.length ? `(${parameters.join(", ")})` : "";
        const res = await fetch(this.__uri, {
            method: "POST",
            headers: { "content-type": "application/json" },
            body: JSON.stringify({
                query: `
          query TFGridClientQuery${p} {
            ${query}
          }
        `,
                variables,
            }),
        });
        const { data } = await res.json();
        return name ? data[name] : data;
    }
    merge(queries) {
        const options = [];
        for (const query in queries) {
            options.push(this[`__${query}`].apply(this, queries[query]));
        }
        const mergedOptions = options.reduce((o, { parameters, query, variables }) => {
            o.parameters = [...o.parameters, ...parameters];
            o.query += ` ${query}`;
            o.variables = Object.assign(Object.assign({}, o.variables), variables);
            return o;
        }, {
            name: null,
            parameters: [],
            query: "",
            variables: {},
        });
        return this._request(mergedOptions);
    }
}
for (const [entity, query] of Object.entries(LIST_QUERIES)) {
    Object.defineProperty(TFGridGqlClient.prototype, `__${query}`, {
        value(fields, options) {
            return this._list(Object.assign({ name: query, entity, fields }, options));
        },
    });
    Object.defineProperty(TFGridGqlClient.prototype, query, {
        value(fields, options) {
            return this._request(this[`__${query}`](fields, options));
        },
    });
}
for (const query of Object.values(BY_ID_QUERIES)) {
    Object.defineProperty(TFGridGqlClient.prototype, `__${query}`, {
        value(id, fields) {
            return this._byId(id, fields, query);
        },
    });
    Object.defineProperty(TFGridGqlClient.prototype, query, {
        value(id, fields) {
            return this._request(this[`__${query}`](id, fields));
        },
    });
}
for (const query of Object.values(CONNECTION_QUERIES)) {
    Object.defineProperty(TFGridGqlClient.prototype, `__${query}`, {
        value(fields, options) {
            return this._connection(fields, options, query);
        },
    });
    Object.defineProperty(TFGridGqlClient.prototype, query, {
        value(fields, options) {
            return this._request(this[`__${query}`](fields, options));
        },
    });
}
//# sourceMappingURL=client.js.map